==> helm-annotations-3.7.6-sources.jar: io/dekorate/helm/config/ValuesSchemaBuilder.java <==
package io.dekorate.helm.config;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;

 /**
  * Generated
  */
public class ValuesSchemaBuilder extends ValuesSchemaFluentImpl<ValuesSchemaBuilder> implements VisitableBuilder<ValuesSchema,ValuesSchemaBuilder>{
  public ValuesSchemaBuilder() {
    this(false);
  }
  public ValuesSchemaBuilder(Boolean validationEnabled) {
    this(new ValuesSchema(), validationEnabled);
  }
  public ValuesSchemaBuilder(ValuesSchemaFluent<?> fluent) {
    this(fluent, false);
  }
  public ValuesSchemaBuilder(ValuesSchemaFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new ValuesSchema(), validationEnabled);
  }
  public ValuesSchemaBuilder(ValuesSchemaFluent<?> fluent,ValuesSchema instance) {
    this(fluent, instance, false);
  }
  public ValuesSchemaBuilder(ValuesSchemaFluent<?> fluent,ValuesSchema instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withTitle(instance.getTitle()); 
    fluent.withProperties(instance.getProperties()); 
    this.validationEnabled = validationEnabled; 
  }
  public ValuesSchemaBuilder(ValuesSchema instance) {
    this(instance,false);
  }
  public ValuesSchemaBuilder(ValuesSchema instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withTitle(instance.getTitle()); 
    this.withProperties(instance.getProperties()); 
    this.validationEnabled = validationEnabled; 
  }
  ValuesSchemaFluent<?> fluent;
  Boolean validationEnabled;
  public EditableValuesSchema build() {
    EditableValuesSchema buildable = new EditableValuesSchema(fluent.getTitle(),fluent.getProperties());
    return buildable;
  }
  
}

==> helm-annotations-4.0.0-sources.jar: io/dekorate/helm/config/ValuesSchemaBuilder.java <==
package io.dekorate.helm.config;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;

 /**
  * Generated
  */
public class ValuesSchemaBuilder extends ValuesSchemaFluent<ValuesSchemaBuilder> implements VisitableBuilder<ValuesSchema,ValuesSchemaBuilder>{
  public ValuesSchemaBuilder() {
    this(false);
  }
  public ValuesSchemaBuilder(Boolean validationEnabled) {
    this(new ValuesSchema(), validationEnabled);
  }
  public ValuesSchemaBuilder(ValuesSchemaFluent<?> fluent) {
    this(fluent, false);
  }
  public ValuesSchemaBuilder(ValuesSchemaFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new ValuesSchema(), validationEnabled);
  }
  public ValuesSchemaBuilder(ValuesSchemaFluent<?> fluent,ValuesSchema instance) {
    this(fluent, instance, false);
  }
  public ValuesSchemaBuilder(ValuesSchemaFluent<?> fluent,ValuesSchema instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new ValuesSchema());

    if (instance != null) {
      fluent.withTitle(instance.getTitle());
      fluent.withProperties(instance.getProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public ValuesSchemaBuilder(ValuesSchema instance) {
    this(instance,false);
  }
  public ValuesSchemaBuilder(ValuesSchema instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new ValuesSchema());

    if (instance != null) {
      this.withTitle(instance.getTitle());
      this.withProperties(instance.getProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  ValuesSchemaFluent<?> fluent;
  Boolean validationEnabled;
  public EditableValuesSchema build() {
    EditableValuesSchema buildable = new EditableValuesSchema(fluent.getTitle(),fluent.buildProperties());
    return buildable;
  }
  
}
